@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.1/classes/src/DwmMcroverLocalHostConfig.cc 12186 $
-// @(#) $Id: DwmMcroverLocalHostConfig.cc 12186 2023-06-21 03:04:41Z dwm $
+// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/classes/src/DwmMcroverLocalHostConfig.cc 12283 $
+// @(#) $Id: DwmMcroverLocalHostConfig.cc 12283 2023-11-14 05:05:22Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020, 2023
 //  All rights reserved.
@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmMcroverLocalHostConfig.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.1/classes/src/DwmMcroverLocalHostConfig.cc 12186 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/classes/src/DwmMcroverLocalHostConfig.cc 12283 $");
 
 namespace Dwm {
 
@@ -106,6 +106,22 @@ namespace Dwm {
     {
       return _disks;
     }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    const map<string,uint64_t> & LocalHostConfig::Dumps() const
+    {
+      return _dumps;
+    }
+    
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    map<string,uint64_t> & LocalHostConfig::Dumps()
+    {
+      return _dumps;
+    }
     
     //------------------------------------------------------------------------
     //!  
@@ -296,6 +312,66 @@ namespace Dwm {
       return;
     }
 
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static string PeriodString(uint64_t dur)
+    {
+      string  rc;
+      uint64_t  w = dur / (7 * 24 * 60 * 60);
+      if (w) {
+        rc += to_string(w) + 'w';
+        dur -= (w * 7 * 24 * 60 * 60);
+      }
+      uint64_t  d = dur / (24 * 60 * 60);
+      if (d) {
+        rc += to_string(d) + 'd';
+        dur -= (d * 24 * 60 * 60);
+      }
+      uint64_t  h = dur / (60 * 60);
+      if (h) {
+        rc += to_string(h) + 'h';
+        dur -= (h * 60 * 60);
+      }
+      uint64_t  m = dur / 60;
+      if (m) {
+        rc += to_string(m) + 'm';
+        dur -= (m * 60);
+      }
+      if (dur) {
+        rc += to_string(dur) + 's';
+      }
+      return rc;
+    }
+    
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static void PrintDumps(ostream & os,
+                           const map<string,uint64_t> & dumps)
+    {
+      if (! dumps.empty()) {
+        os << "    #---------------------------------------------------------"
+          "---------------\n"
+           << "    #  Check that a 'dump' of the given devices has occurred"
+          " within the\n"
+           << "    #  given time interval.\n"
+           << "#-------------------------------------------------------------"
+           << "-----------\n";
+        os << "    DUMPS = [\n";
+        auto  iter = dumps.begin();
+        os << "        { device = \"" << iter->first << "\"; period = "
+           << PeriodString(iter->second) << "; }";
+        ++iter;
+        for (; iter != dumps.end(); ++iter) {
+          os << ",\n        { device = \"" << iter->first << "\"; period = "
+             << PeriodString(iter->second) << "; }";
+        }
+        os << "\n    ];\n\n";
+      }
+      return;
+    }
+    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -383,6 +459,7 @@ namespace Dwm {
 
       PrintZpools(os, cfg._zpools);
       PrintFilesystems(os, cfg._filesystems);
+      PrintDumps(os, cfg._dumps);
       PrintDisks(os, cfg._disks);
       PrintRoutes(os, cfg._routes);
       PrintGuests(os, cfg._guests);
@@ -408,6 +485,9 @@ namespace Dwm {
       for (auto disk : _disks) {
         j["disks"][disk.first] = disk.second;
       }
+      for (auto dump : _dumps) {
+        j["dumps"][dump.first] = dump.second;
+      }
       for (auto route : _routes) {
         size_t  i = 0;
         for (auto pfx : route.second) {
@@ -466,6 +546,29 @@ namespace Dwm {
       return rc;
     }
 
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static bool FromJsonMap(const nlohmann::json & j,
+                            map<string,uint64_t> & m)
+    {
+      bool  rc = false;
+      m.clear();
+      if (j.is_object()) {
+        auto  it = j.begin();
+        for ( ; it != j.end(); ++it) {
+          if (it.value().is_number()) {
+            m[it.key()] = it.value().get<uint64_t>();
+          }
+          else {
+            break;
+          }
+        }
+        rc = (j.end() == it);
+      }
+      return rc;
+    }
+    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -563,6 +666,10 @@ namespace Dwm {
         if (it != j.end()) {
           rc &= FromJsonMap(*it, _disks);
         }
+        it = j.find("dumps");
+        if (it != j.end()) {
+          rc &= FromJsonMap(*it, _dumps);
+        }
         it = j.find("routes");
         if (it != j.end()) {
           rc &= FromJsonMap(*it, _routes);
